@@ -1,9 +1,24 @@
 import ImageCaptureCore
-from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure
-import objc
+from PyObjCTools.TestSupport import (
+    TestCase,
+    min_os_level,
+    max_os_level,
+)
 
 
 class TestICDevice(TestCase):
+    def test_typed_enum(self):
+        self.assertIsTypedEnum(ImageCaptureCore.ICDeviceCapability, str)
+        self.assertIsTypedEnum(ImageCaptureCore.ICDeviceLocationOptions, str)
+        self.assertIsTypedEnum(ImageCaptureCore.ICDeviceStatus, str)
+        self.assertIsTypedEnum(ImageCaptureCore.ICDeviceTransport, str)
+        self.assertIsTypedEnum(ImageCaptureCore.ICSessionOptions, str)
+
+    def test_enum_types(self):
+        self.assertIsEnumType(ImageCaptureCore.ICDeviceLocationType)
+        self.assertIsEnumType(ImageCaptureCore.ICDeviceType)
+        self.assertIsEnumType(ImageCaptureCore.ICDeviceTypeMask)
+
     def testConstants(self):
         self.assertEqual(ImageCaptureCore.ICDeviceTypeCamera, 0x00000001)
         self.assertEqual(ImageCaptureCore.ICDeviceTypeScanner, 0x00000002)
@@ -52,11 +67,10 @@ class TestICDevice(TestCase):
         self.assertIsInstance(ImageCaptureCore.ICEnumerationChronologicalOrder, str)
 
     def testProtocolObjects(self):
-        objc.protocolNamed("ICDeviceDelegate")
+        self.assertProtocolExists("ICDeviceDelegate")
 
     def testMethods(self):
         self.assertResultIsBOOL(ImageCaptureCore.ICDevice.isRemote)
-        self.assertResultIsBOOL(ImageCaptureCore.ICDevice.hasConfigurableWiFiInterface)
         self.assertResultIsBOOL(ImageCaptureCore.ICDevice.hasOpenSession)
 
         self.assertArgIsSEL(
@@ -65,7 +79,7 @@ class TestICDevice(TestCase):
             b"v@:I@@^v",
         )
 
-    @expectedFailure
+    @max_os_level("10.14")
     def testMethods_removed_in_10_15(self):
         self.assertResultIsBOOL(ImageCaptureCore.ICDevice.isShared)
 
